@@ -7,30 +7,44 @@ use strict;
 use utf8;
 use base 'POD2::Base';
 
-our $VERSION = '5.18.0.1.76';
+our $VERSION = '5.18.0.1.77';
 
 # Versions list
 sub pod_info {
-    perl              => '5.18.0.1',
-      perlintro       => '5.18.0.1',
-      perlrun         => '5.18.0.1',
-      a2p             => '5.18.0.1',
-      perlbook        => '5.18.0.1',
-      perldoc         => '5.18.0.1',
-      perlpragma      => '5.18.0.1',
-      perlstyle       => '5.18.0.1',
-      perlcheat       => '5.18.0.1',
-      perlnewmod      => '5.18.0.1',
-      perlrequick     => '5.18.0.1',
-      perlreref       => '5.18.0.1',
-      perlunicode     => '5.18.0.1',
-      perlretut       => '5.18.0.1',
-      perlreguts      => '5.18.0.1',
-      perlrecharclass => '5.18.0.1',
-      perlrebackslash => '5.18.0.1',
-      perlreapi       => '5.18.0.1',
-      perlre          => '5.18.0.1',
-      perlsecret      => '5.18.0.1',
+    'a2p.pod'               => '5.18.0.1',
+      'perlbook.pod'        => '5.18.0.1',
+      'perlcheat.pod'       => '5.18.0.1',
+      'perldebtut.pod'      => '5.18.0.1',
+      'perldoc.pod'         => '5.18.0.1',
+      'perlguts.pod'        => '5.18.0.1',
+      'perlhacktut.pod'     => '5.18.0.1',
+      'perlintro.pod'       => '5.18.0.1',
+      'perlmod.pod'         => '5.18.0.1',
+      'perlnewmod.pod'      => '5.18.0.1',
+      'perlootut.pod'       => '5.18.0.1',
+      'perlopentut.pod'     => '5.18.0.1',
+      'perlpacktut.pod'     => '5.18.0.1',
+      'perl.pod'            => '5.18.0.1',
+      'perlpod.pod'         => '5.18.0.1',
+      'perlpodspec.pod'     => '5.18.0.1',
+      'perlpodstyle.pod'    => '5.18.0.1',
+      'perlpragma.pod'      => '5.18.0.1',
+      'perlreapi.pod'       => '5.18.0.1',
+      'perlrebackslash.pod' => '5.18.0.1',
+      'perlrecharclass.pod' => '5.18.0.1',
+      'perlreftut.pod'      => '5.18.0.1',
+      'perlreguts.pod'      => '5.18.0.1',
+      'perlre.pod'          => '5.18.0.1',
+      'perlrequick.pod'     => '5.18.0.1',
+      'perlreref.pod'       => '5.18.0.1',
+      'perlretut.pod'       => '5.18.0.1',
+      'perlrun.pod'         => '5.18.0.1',
+      'perlsecret.pod'      => '5.18.0.1',
+      'perlstyle.pod'       => '5.18.0.1',
+      'perlthrtut.pod'      => '5.18.0.1',
+      'perlunicode.pod'     => '5.18.0.1',
+      'perluniintro.pod'    => '5.18.0.1',
+      'perlunitut.pod'      => '5.18.0.1',
       ;
 }
 
@@ -62,13 +76,18 @@ POD2::RU - документация Perl по-русски
 
   use POD2::RU;
   print_pods();
-  print_pod('pod_foo', 'pod_baz');
+  print_pod('perlre', 'perlootut');
 
 =head1 DESCRIPTION
 
-Модуль POD2::RU содержит перевод Perl-документации на русский. 
+POD2::RU - проект перевода Perl-документации на русский язык.
+
+=head1 REPOSITORY
+
 Домашняя страница проекта ─ L<https://github.com/mishin/POD-to-RU>. 
 
+=head1 USAGE
+
 Примеры использования
 
   perldoc POD2::RU::perlretut
